@@ -5,12 +5,6 @@
 #ifndef __MED_ALGO_H__
 #define __MED_ALGO_H__
 
-#if __GNUC__  >= 5 || (defined(_MSC_VER) && !defined(_DEBUG))
-#define NEW_COMPLIER false
-#else
-#define NEW_COMPLIER false
-#endif
-
 #include <Logger/Logger/Logger.h>
 #include <MedUtils/MedUtils/MedUtils.h>
 #include <MedStat/MedStat/MedStat.h>
