@@ -332,6 +332,7 @@ template int medial::process::binary_search_index(const int *begin, const int *e
 template int medial::process::binary_search_index(const double *begin, const double *end, double val);
 template int medial::process::binary_search_index(const string *begin, const string *end, string val);
 
+#if !defined(MES_LIBRARY)
 string medial::print::print_any(po::variable_value &a) {
 	if (a.value().type() == typeid(string)) {
 		return a.as<string>();
@@ -498,6 +499,8 @@ int medial::io::ProgramArgs_base::parse_parameters(int argc, char *argv[]) {
 
 	return 0;
 }
+#endif
+
 
 template<class ContainerType> string medial::io::get_list(const ContainerType &ls, const string &delimeter) {
 	string res = "";
